@@ -134,6 +134,9 @@ function read (name, ver, forceBypass, cb) {
 
   var root = cachedPackageRoot({name : name, version : ver})
   function c (er, data) {
+    log.silly("cache", "addNamed cb", name+"@"+ver)
+    if (er) log.verbose("cache", "addNamed error for", name+"@"+ver, er)
+
     if (data) deprCheck(data)
 
     return cb(er, data)
@@ -268,7 +271,7 @@ function add (args, where, cb) {
   if (adding <= 0) {
     npm.spinner.start()
   }
-  adding ++
+  adding++
   cb = afterAdd(cb)
 
   realizePackageSpecifier(spec, where, function (err, p) {
@@ -322,24 +325,23 @@ function unpack (pkg, ver, unpackTarget, dMode, fMode, uid, gid, cb) {
 
 function afterAdd (cb) { return function (er, data) {
   adding--
-  if (adding <= 0) {
-    npm.spinner.stop()
-  }
-  if (er || !data || !data.name || !data.version) {
-    return cb(er, data)
-  }
+  if (adding <= 0) npm.spinner.stop()
+
+  if (er || !data || !data.name || !data.version) return cb(er, data)
+  log.silly("cache", "afterAdd", data.name+"@"+data.version)
 
   // Save the resolved, shasum, etc. into the data so that the next
   // time we load from this cached data, we have all the same info.
   var pj = path.join(cachedPackageRoot(data), "package", "package.json")
 
   var done = inflight(pj, cb)
-  if (!done) return log.verbose("afterAdd", pj, "already in flight; waiting")
+  if (!done) return log.verbose("afterAdd", pj, "already in flight; not writing")
   log.verbose("afterAdd", pj, "not in flight; writing")
 
   getStat(function (er, cs) {
     if (er) return done(er)
     writeFileAtomic(pj, JSON.stringify(data), {chown : cs}, function (er) {
+      if (!er) log.verbose("afterAdd", pj, "written")
       return done(er, data)
     })
   })
