@@ -28,10 +28,6 @@ module.exports = function addRemoteGit (u, silent, cb) {
   assert(typeof u === "string", "must have git URL")
   assert(typeof cb === "function", "must have callback")
 
-  cb = inflight(u, cb)
-
-  if (!cb) return
-
   log.verbose("addRemoteGit", "u=%j silent=%j", u, silent)
   var parsed = url.parse(u, true)
   log.silly("addRemoteGit", "parsed", parsed)
@@ -50,6 +46,10 @@ module.exports = function addRemoteGit (u, silent, cb) {
     u = u.replace(/^ssh:\/\//, "")
   }
 
+  cb = inflight(u, cb)
+  if (!cb) return log.verbose("addRemoteGit", u, "already in flight; waiting")
+  log.verbose("addRemoteGit", u, "not in flight; cloning")
+
   // figure out what we should check out.
   var co = parsed.hash && parsed.hash.substr(1) || "master"
 
@@ -142,10 +142,7 @@ function archiveGitRemote (p, u, co, origUrl, cb) {
     }
     log.verbose("git fetch -a origin ("+u+")", stdout)
     tmp = path.join(npm.tmp, Date.now()+"-"+Math.random(), "tmp.tgz")
-    verifyOwnership()
-  })
 
-  function verifyOwnership() {
     if (process.platform === "win32") {
       log.silly("verifyOwnership", "skipping for windows")
       resolveHead()
@@ -164,7 +161,7 @@ function archiveGitRemote (p, u, co, origUrl, cb) {
         })
       })
     }
-  }
+  })
 
   function resolveHead () {
     git.whichAndExec(resolve, {cwd: p, env: env}, function (er, stdout, stderr) {
@@ -227,7 +224,7 @@ function gitEnv () {
   if (gitEnv_) return gitEnv_
   gitEnv_ = {}
   for (var k in process.env) {
-    if (!~["GIT_PROXY_COMMAND","GIT_SSH","GIT_SSL_NO_VERIFY"].indexOf(k) && k.match(/^GIT/)) continue
+    if (!~["GIT_PROXY_COMMAND","GIT_SSH","GIT_SSL_NO_VERIFY","GIT_SSL_CAINFO"].indexOf(k) && k.match(/^GIT/)) continue
     gitEnv_[k] = process.env[k]
   }
   return gitEnv_
